@@ -1,6 +1,19 @@
 <?php
+/**
+ * This is where I put stuff that is specific to this plugin.. but
+ * does not belong in the class.  Most of the output screens are done
+ * here. This is also where you can customize how errors are handled.
+ *
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @author Jared Watkins 2003 <jared@watkins.net>
+ * @package amavisnewsql
+ * $Id: functions.php, v
+*/
 
-function amavisnewsql_ErrorOut($err) {
+/**
+ * Handles all error output
+ */
+function amavisnewsql_ErrorOut($err, $fatal=false) {
    global $color;
    if (is_array($err)) {
        print_r($err);
@@ -8,24 +21,29 @@ function amavisnewsql_ErrorOut($err) {
        $prev = bindtextdomain ('squirrelmail', SM_PATH . 'locale');
        textdomain ('squirrelmail');
        displayPageHeader($color, 'None');
-       echo "<h3><font color=$color[2]>Error: $err</font></h3>";
+       echo "<h3><font color=red>Error: $err</font></h3>";
        $prev = bindtextdomain ('amavisnewsql', SM_PATH . 'plugins/amavisnewsql/locale');
        textdomain ('amavisnewsql');
    }
+   if($fatal) die();
 }
 
-
-function amavisnewsql_PrintAddEditWB($action, $row = '') {
+/**
+ * This prints the top section for adding / editing your W/B list
+ */
+function amavisnewsql_PrintAddEditWB($action, $row = '', $calledfrom=NULL, $line=NULL) {
    global $color, $dbfp, $username;
 
    if($action == 'prep_edit') {
-      $title = _("Edit Address");
+      $title = "Edit Address";
       $action = "add_edit_wb_address";
 
-      if (!$wbList = $dbfp->ReadWBList($username)) {
-         amavisnewsql_ErrorOut($dbfp->error);
+      $wbList = $dbfp->ReadWBList($username, $calledfrom, $line);
+      if (!$wbList && $wbList != null) {
+         amavisnewsql_ErrorOut($dbfp->error, TRUE);
       }
 
+
       for($i=0; $i < count($wbList); $i++) {
           if($wbList[$i]["row"] == $row) {
              $address = $wbList[$i]["address"];
@@ -55,6 +73,7 @@ friend@aol.com  whitelist  7 (" . _("complete address") . ")" . _(" OR") . "
 friend          whitelist  7 (" . _("complete part before domain") . ")
 @aol.com        blacklist  6 (" . _("domain only including the ") . "@)
                   </pre>
+                  <a href=\"amavisnewsql.php?action=whitelist_abook\">" . _("Whitelist Everyone In Your Address Book") ."</a>
                   </td>
                 </tr>
                 <tr>
@@ -83,7 +102,6 @@ friend          whitelist  7 (" . _("complete part before domain") . ")
                 </tr>
                 <tr>
                   <td></td><td><input type=\"submit\" value=\"$title\" name=\"submit\"><br><br>
-                  <a href=\"amavisnewsql.php?action=whitelist_abook\">" . _("Whitelist Everyone In Your Address Book") ."</a>
                   </td>
 
                 </tr>
@@ -95,9 +113,9 @@ friend          whitelist  7 (" . _("complete part before domain") . ")
    ";
 }
 
-
-// ---------------------------------------------------------------------
-
+/**
+ * Displays the little popup window of global W/B lists
+ */
 function amavisnewsql_DisplayGlobalList() {
    global $dbfp, $color;
 
@@ -110,12 +128,10 @@ function amavisnewsql_DisplayGlobalList() {
          and $dbfp->users_table.id = '$dbfp->global_user_id'
          order by $dbfp->wblist_table.priority";
 
-   bindtextdomain ('amavisnewsql', SM_PATH . 'plugins/amavisnewsql/locale');
-   textdomain ('amavisnewsql');
 
    echo"<table border=\"0\" width=\"100%\" align=\"center\" cellpadding=\"2\" cellspacing=\"0\">
              <tr>
-                <td colspan=\"3\" align=\"center\" bgcolor=\"$color[3]\"><b>" ._("Global White/Black Lists") . "</b>
+                <td colspan=\"3\" align=\"center\" bgcolor=\"$color[3]\"><b>Global White/Black Lists</b>
                 </td>
              </tr>
              <tr bgcolor=\"$color[5]\">
@@ -127,34 +143,32 @@ function amavisnewsql_DisplayGlobalList() {
 
 
 
-   $res = $dbfp->db->query($q);
-   if (DB::isError($res)) {
-            $dberr = $dbfp->db->getMessage();
-            amavisnewsql_ErrorOut("amavisnewsql_DisplayGlobalList Running Global Query Database Error: $dberr");
-            exit;
+   if (!$res = $dbfp->sqlRead($q, __FILE__, __LINE__)) {
+       amavisnewsql_ErrorOut("amavisnewsql_DisplayGlobalList Running Global Query Database Error: $dbfp->error");
+
    } else {
 
     for($i=0; $i < $res->numRows(); $i++) {
        $row = $res->fetchRow(DB_FETCHMODE_ASSOC);
-       if($row["wb"] == "W") $type = _("Whitelist");
-         else $type = _("Blacklist");
+       if($row["wb"] == "W") $type = "Whitelist";
+         else $type = "Blacklist";
        echo "<tr><td>$row[email]</td><td>$type</td><td>$row[priority]</td></tr>";
 
     }
 
    echo "</table>";
 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
+
+
 
    }
+
 }
 
-
-// ---------------------------------------------------------------------
-
-
-function amavisnewsql_DisplayOptions($action = '', $row = '') {
+/**
+ * Prints the form that allows you to set your SA options
+ */
+function amavisnewsql_DisplayOptions($action = '', $row = '', $calledfrom=NULL, $line=NULL) {
   global $CONFIG, $dbfp, $username, $color;
 
   if($CONFIG["use_quarantine"]) {
@@ -199,12 +213,13 @@ function amavisnewsql_DisplayOptions($action = '', $row = '') {
 
              <!-- User's white/black list -->
    ";
-      if(!$wbList = $dbfp->ReadWBList($username)) {
-         amavisnewsql_ErrorOut($dbfp->error);
+      $wbList = $dbfp->ReadWBList($username, $calledfrom, $line);
+      if (!$wbList && $wbList != null) {
+         amavisnewsql_ErrorOut($dbfp->error, TRUE);
       }
 
 
-     if($wbList == -1) {
+     if(count($wbList) == 0) {
         echo "<tr><td><b><font color=red>" . _("No Personal Addresses Defined") . "</b>
               </td></tr>";
      } else {
@@ -224,9 +239,9 @@ function amavisnewsql_DisplayOptions($action = '', $row = '') {
 
             echo "<td>".$wbList[$j]["priority"]."</td>";
             echo "<td>
-                  <a href=$_SERVER[PHP_SELF]?action=prep_edit_wb_address&row=".$wbList[$j]["row"].">". _("Edit") . "</a>
+                  <a href=$_SERVER[PHP_SELF]?action=prep_edit_wb_address&row=".$wbList[$j]["row"].">Edit</a>
                   &nbsp
-                  <a href=$_SERVER[PHP_SELF]?action=delete_wb_address&row=".$wbList[$j]["row"].">". _("Delete") . "</a>
+                  <a href=$_SERVER[PHP_SELF]?action=delete_wb_address&row=".$wbList[$j]["row"].">Delete</a>
                   </td></tr>";
         }
      } //if else
@@ -263,12 +278,12 @@ echo "
  <!-- Policy Setting -->
 ";
 
-if (!$policyList = $dbfp->ReadPolicyList()) {
-   amavisnewsql_ErrorOut($dbfp->error);
+if (!$policyList = $dbfp->ReadPolicyList("%", $calledfrom, $line)) {
+   amavisnewsql_ErrorOut($dbfp->error, TRUE);
 }
 
-if (!$myPolicy = $dbfp->ReadPolicyList($username)) {
-   amavisnewsql_ErrorOut($dbfp->error);
+if (!$myPolicy = $dbfp->ReadPolicyList($username, $calledfrom, $line)) {
+   amavisnewsql_ErrorOut($dbfp->error, TRUE);
 }
 
 if(count($policyList) == 0) {
@@ -276,8 +291,8 @@ if(count($policyList) == 0) {
      } else {
 
          if($CONFIG["use_quarantine"]) {
-             if (!$quarantine = $dbfp->ReadQuarantineSettings($username)) {
-                 amavisnewsql_ErrorOut($dbfp->error);
+             if (!$quarantine = $dbfp->ReadQuarantineSettings($username, $calledfrom, $line)) {
+                 amavisnewsql_ErrorOut($dbfp->error, TRUE);
              }
             echo "
                  <form action=\"$_SERVER[PHP_SELF]\">
@@ -291,7 +306,7 @@ if(count($policyList) == 0) {
                        <table border=\"0\" width=\"100%\" cellpadding=\"1\" cellspacing=\"1\">
                          <tr>
                               <td height=\"30\">" . _("How often should you receive quarantine reports?") ."</td>
-                              <td><i>" . _("Currently:") ."</i> " . _("$quarantine[freq]") . " <br>
+                              <td><i>" . _("Currently:") ."</i> $quarantine[freq] <br>
 
                                   <select name=\"frequency\">
                                   <option selected value=\"\"></option>
@@ -303,12 +318,13 @@ if(count($policyList) == 0) {
                                   </select>
 
                               </td>
-                          </tr>
-                          <tr>
+                         </tr>
+                         <tr><td height=\"10\"></td></tr>
+                         <tr>
                               <td height=\"30\">" . _("How long should mail stay in the quarantine before being automatically removed?") . "</td>
 
                               <td>
-                                  <i>" . _("Currently:") ."</i> " . _("$quarantine[retention]") . "<br>
+                                  <i>" . _("Currently:") ."</i> $quarantine[retention]<br>
                                   <select name=\"retention\">
                                   <option selected value=\"\"></option>
                                   <option value=\"3\">" . _("3 Days") ."</option>
@@ -319,8 +335,22 @@ if(count($policyList) == 0) {
                                   <option value=\"20\">" . _("20 Days") ."</option>
                                   <option value=\"30\">" . _("30 Days") ."</option>
                                   </select>
-                          </tr>
-                          <tr>
+                              </td>
+                         </tr>
+                         <tr><td height=\"10\"></td></tr>
+                         <tr>
+                              <td height=\"30\">" . _("Should messages be quarantined or rejected when reaching the higher Score Level?") ."</td>
+
+                              <td>
+                                   <i>" . _("Currently:") . "</i> $quarantine[onoff]<br>
+                                   <select name=\"quarantineonoff\">
+                                   <option selected value=\"\"></option>
+                                   <option value=\"1\">" ._("Use Quarantine") . "</option>
+                                   <option value=\"0\">" ._("Reject High Scoring Email") . "</option>
+                                   </select>
+                              </td>
+                         </tr>
+                         <tr>
                               <td> </td>
                               <td valign=\"bottom\" height=\"40\">
                                   <input type=\"submit\" value=\"" . _("Set Quarantine Policy") . "\">
@@ -392,7 +422,7 @@ if(count($policyList) == 0) {
                         _("The tag level is the numerical score required to identify a message as being spam.  This will cause *SPAM* to be added to the subject line and the X-Spam-Flag header to be set to YES.") . "
                      </td>
                      <td colspan=2 valign=\"top\" bgcolor=\"$color[4]\"><center><b>$tag2_label</b></center><br>" .
-                        _("The ") . $tag2_label . _(" is the numerical score required to prevent delivery of a message at the server.  This level should be higher or equal to Tag Level and high enough to avoid catching legitimate email. As your custom whitelist grows you should adjust these two levels to tag and block more spam.") . "
+                        _("The ") . _("$tag2_label") . _(" is the numerical score required to prevent delivery of a message at the server.  This level should be higher or equal to Tag Level and high enough to avoid catching legitimate email. As your custom whitelist grows you should adjust these two levels to tag and block more spam.") . "
                      </td>
                  </tr>
           </table>
@@ -404,4 +434,4 @@ if(count($policyList) == 0) {
 $dbfp->disconnect();
 echo "</body></html>";
 } //function amavisnewsql_DisplayOptions
-?>
\ No newline at end of file
+?>
