@@ -1,9 +1,9 @@
-#!/usr/local/bin/php
+#!/usr/local/bin/php -q
 <?php
 /**
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @author Jared Watkins 2003 <jared@watkins.net>
- * @package amavisnewsql 
+ * @package amavisnewsql
  * $Id: process_bsmtp.php, v
  *
  * This script picks up messages that are quarantined by amavis-new
@@ -28,7 +28,7 @@ include(BASEINCLUDE."amavisnewsql.class.php");
 include "Log.php";
 
 
-$dbfp = new AmavisNewSQL();
+$dbfp = new AmavisNewSQL($CONFIG);
 $dbfp->connect();
 
 $conf  = array();
@@ -98,7 +98,8 @@ function process_file($dbfp, $file) {
                     $scanstate = "skiptext";
                 } else if (preg_match("/^Subject: (.*)/", $line, $match)) {
                     $store["subject"] = trim($match[1]);
-                } else if (preg_match("/^X-Spam-Status:.*hits=([0-9]{1,2}\.[0-9])/", $line, $match)) {
+#                } else if (preg_match("/^X-Spam-Status:.*hits=([0-9]{1,2}\.[0-9])/", $line, $match)) {
+                } else if (preg_match("/^X-Spam-Status:.*hits=([0-9]+\.[0-9]+)/", $line, $match)) {
                     $store["score"] = trim($match[1]);
                 }
                 $store["body"] .= $line;
@@ -114,33 +115,75 @@ function process_file($dbfp, $file) {
     } //while
 
     if (count($rcpt) == 0) {
-        $log->log("$file - no recipients", LOG_INFO);
+        $log->log("ERROR: $file - no recipients", LOG_ERR);
+        return;
     }
 
     foreach ($store as $key => $value) {
-         $store[$key] = $dbfp->db->quoteString($value);
+         #$store[$key] = $dbfp->db->quoteSmart($value);
+         $store[$key] = addslashes($value);
     }
 
     $nextid  = $dbfp->db->nextID("msg_id");
 
-    $q = "insert into $dbfp->msg_table (id, stype, sender, subject, body, storetime, score)
-                      values ($nextid, '$store[stype]', '$store[sender]', '$store[subject]',
-                              '$store[body]', '$store[storetime]', '$store[score]')";
-
-    if (!$dbfp->sqlWrite($q, __FUNCTION__, __LINE__)) {
-        $log->log("$file - Failed to update message database: $dbfp->error", LOG_ERR);
-        rename(QUARANTINEDIR."/$file", QUARANTINEDIR."/.notstored/$file");
-        return;
-    }
-
     // Now lookup recipient names using amavis style lookups
-
+/*
     foreach ($rcpt as $receiver) {
         $userid = $dbfp->uid($receiver);
+
+        if (!$userid) {
+            $log->log("ERROR: Recipient $receiver in $file does not exist in the database. Message NOT stored.", LOG_ERR);
+            rename(QUARANTINEDIR."/$file", QUARANTINEDIR."/.notstored/$file");
+            return;
+        }
+
         if ($userid) {
             $userlist[$nextid] = $userid;
         }
     }
+*/
+
+    foreach ($rcpt as $receiver) {
+        $userid = $dbfp->uid($receiver);
+
+        if (!$userid) {
+
+            continue;
+        
+        } else {
+        
+            $userlist[$nextid] = $userid;
+        
+        }
+    }
+    
+    
+    if (count($userlist) == 0) {
+        $log->log("ERROR: No Recipients in $file exist in the database. Message NOT stored.", LOG_ERR);
+        rename(QUARANTINEDIR."/$file", QUARANTINEDIR."/.notstored/$file");
+        return;
+    }
+
+
+
+    # Since I'm using the smartquote call instead of the old one.. I no longer need to quote
+    # those insert vars.. right? Wrong.. smartquote is not a substuite for addslashes
+    #
+    
+    $q = "insert into $dbfp->msg_table (id, stype, sender, subject, body, storetime, score)
+                      values ($nextid, '$store[stype]', '$store[sender]', '$store[subject]',
+                              '$store[body]', '$store[storetime]', '$store[score]')";
+
+#                      values ($nextid, $store[stype], $store[sender], $store[subject],
+#                              $store[body], $store[storetime], $store[score])";
+
+
+    if (!$dbfp->sqlWrite($q, __FUNCTION__, __LINE__)) {
+        $log->log("$file - Failed to insert message into database: $dbfp->error. Message moved to notstored directory.", LOG_ERR);
+        rename(QUARANTINEDIR."/$file", QUARANTINEDIR."/.notstored/$file");
+        return;
+    }
+
 
     foreach ($userlist as $key => $value) {
         $q = "insert into $dbfp->msgowner_table (msgid, rid) values ($key, $value)";
